"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDebouncedValue = void 0;
var _react = require("react");
/**
 * Get value after a delay. If value changes within the delay period, the timeout gets cleared and restarted.
 * @param value current value to debounce
 * @param delay time to wait before updating the debounced value
 * @returns debounced value
 */
const useDebouncedValue = (value, delay) => {
  // State and setters for debounced value
  const [debouncedValue, setDebouncedValue] = (0, _react.useState)(value);
  (0, _react.useEffect)(() => {
    // Update debounced value after delay
    const handler = setTimeout(() => {
      setDebouncedValue(value);
    }, delay);
    // Cancel the timeout if value changes (also on delay change or unmount)
    // This is how we prevent debounced value from updating if value is changed ...
    // .. within the delay period. Timeout gets cleared and restarted.
    return () => {
      clearTimeout(handler);
    };
  }, [value, delay] // Only re-call effect if value or delay changes
  );

  return debouncedValue;
};
exports.useDebouncedValue = useDebouncedValue;
//# sourceMappingURL=useDebouncedValue.js.map